# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/protocol/v30/submission_tracking.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/participant/protocol/v30/submission_tracking.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import participant_transaction_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_participant__transaction__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJcom/digitalasset/canton/participant/protocol/v30/submission_tracking.proto\x12\x30\x63om.digitalasset.canton.participant.protocol.v30\x1a\x42\x63om/digitalasset/canton/protocol/v30/participant_transaction.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xf9\x01\n\x0e\x43ompletionInfo\x12\x15\n\x06\x61\x63t_as\x18\x01 \x03(\tR\x05\x61\x63tAs\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x1d\n\ncommand_id\x18\x03 \x01(\tR\tcommandId\x12s\n\x18opt_deduplication_period\x18\x04 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v30.DeduplicationPeriodR\x16optDeduplicationPeriod\x12#\n\rsubmission_id\x18\x05 \x01(\tR\x0csubmissionId\"H\n\x0f\x43ommandRejected\x1a\x35\n\x1bGrpcRejectionReasonTemplate\x12\x16\n\x06status\x18\x01 \x01(\x0cR\x06status\"\x9d\x01\n\x16SubmissionTrackingData\x12w\n\x0btransaction\x18\x01 \x01(\x0b\x32S.com.digitalasset.canton.participant.protocol.v30.TransactionSubmissionTrackingDataH\x00R\x0btransactionB\n\n\x08tracking\"\xc4\x04\n!TransactionSubmissionTrackingData\x12i\n\x0f\x63ompletion_info\x18\x01 \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v30.CompletionInfoR\x0e\x63ompletionInfo\x12\x8b\x01\n\x0frejection_cause\x18\x02 \x01(\x0b\x32\x62.com.digitalasset.canton.participant.protocol.v30.TransactionSubmissionTrackingData.RejectionCauseR\x0erejectionCause\x12\x38\n\x18physical_synchronizer_id\x18\x03 \x01(\tR\x16physicalSynchronizerId\x1a\xeb\x01\n\x0eRejectionCause\x12\x32\n\x07timeout\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x07timeout\x12\x9b\x01\n\x19rejection_reason_template\x18\x02 \x01(\x0b\x32].com.digitalasset.canton.participant.protocol.v30.CommandRejected.GrpcRejectionReasonTemplateH\x00R\x17rejectionReasonTemplateB\x07\n\x05\x63\x61useBaZ_github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.protocol.v30.submission_tracking_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z_github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v30'
  _globals['_COMPLETIONINFO']._serialized_start=226
  _globals['_COMPLETIONINFO']._serialized_end=475
  _globals['_COMMANDREJECTED']._serialized_start=477
  _globals['_COMMANDREJECTED']._serialized_end=549
  _globals['_COMMANDREJECTED_GRPCREJECTIONREASONTEMPLATE']._serialized_start=496
  _globals['_COMMANDREJECTED_GRPCREJECTIONREASONTEMPLATE']._serialized_end=549
  _globals['_SUBMISSIONTRACKINGDATA']._serialized_start=552
  _globals['_SUBMISSIONTRACKINGDATA']._serialized_end=709
  _globals['_TRANSACTIONSUBMISSIONTRACKINGDATA']._serialized_start=712
  _globals['_TRANSACTIONSUBMISSIONTRACKINGDATA']._serialized_end=1292
  _globals['_TRANSACTIONSUBMISSIONTRACKINGDATA_REJECTIONCAUSE']._serialized_start=1057
  _globals['_TRANSACTIONSUBMISSIONTRACKINGDATA_REJECTIONCAUSE']._serialized_end=1292
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.object_meta import ObjectMeta


T = TypeVar("T", bound="User")


@_attrs_define
class User:
    """Users and rights
    /////////////////
     Users are used to dynamically manage the rights given to Daml applications.
     They are stored and managed per participant node.

        Attributes:
            id (str): The user identifier, which must be a non-empty string of at most 128
                characters that are either alphanumeric ASCII characters or one of the symbols "@^$.!`-#+'~_|:".
                Required
            primary_party (str): The primary party as which this user reads and acts by default on the ledger
                *provided* it has the corresponding ``CanReadAs(primary_party)`` or
                ``CanActAs(primary_party)`` rights.
                Ledger API clients SHOULD set this field to a non-empty value for all users to
                enable the users to act on the ledger using their own Daml party.
                Users for participant administrators MAY have an associated primary party.
                Optional,
                Modifiable
            is_deactivated (bool): When set, then the user is denied all access to the Ledger API.
                Otherwise, the user has access to the Ledger API as per the user's rights.
                Optional,
                Modifiable
            identity_provider_id (str): The ID of the identity provider configured by ``Identity Provider Config``
                Optional, if not set, assume the user is managed by the default identity provider.
            metadata (ObjectMeta | Unset): Represents metadata corresponding to a participant resource (e.g. a participant
                user or participant local information about a party).

                Based on ``ObjectMeta`` meta used in Kubernetes API.
                See https://github.com/kubernetes/apimachinery/blob/master/pkg/apis/meta/v1/generated.proto#L640
    """

    id: str
    primary_party: str
    is_deactivated: bool
    identity_provider_id: str
    metadata: ObjectMeta | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        id = self.id

        primary_party = self.primary_party

        is_deactivated = self.is_deactivated

        identity_provider_id = self.identity_provider_id

        metadata: dict[str, Any] | Unset = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "primaryParty": primary_party,
                "isDeactivated": is_deactivated,
                "identityProviderId": identity_provider_id,
            }
        )
        if metadata is not UNSET:
            field_dict["metadata"] = metadata

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.object_meta import ObjectMeta

        d = dict(src_dict)
        id = d.pop("id")

        primary_party = d.pop("primaryParty")

        is_deactivated = d.pop("isDeactivated")

        identity_provider_id = d.pop("identityProviderId")

        _metadata = d.pop("metadata", UNSET)
        metadata: ObjectMeta | Unset
        if isinstance(_metadata, Unset):
            metadata = UNSET
        else:
            metadata = ObjectMeta.from_dict(_metadata)

        user = cls(
            id=id,
            primary_party=primary_party,
            is_deactivated=is_deactivated,
            identity_provider_id=identity_provider_id,
            metadata=metadata,
        )

        user.additional_properties = d
        return user

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/command_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/daml/ledger/api/v2/command_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import commands_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_commands__pb2
from . import reassignment_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_reassignment__pb2
from . import reassignment_commands_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_reassignment__commands__pb2
from . import transaction_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_transaction__pb2
from . import transaction_filter_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_transaction__filter__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,com/daml/ledger/api/v2/command_service.proto\x12\x16\x63om.daml.ledger.api.v2\x1a%com/daml/ledger/api/v2/commands.proto\x1a)com/daml/ledger/api/v2/reassignment.proto\x1a\x32\x63om/daml/ledger/api/v2/reassignment_commands.proto\x1a(com/daml/ledger/api/v2/transaction.proto\x1a/com/daml/ledger/api/v2/transaction_filter.proto\"T\n\x14SubmitAndWaitRequest\x12<\n\x08\x63ommands\x18\x01 \x01(\x0b\x32 .com.daml.ledger.api.v2.CommandsR\x08\x63ommands\"\xbc\x01\n\"SubmitAndWaitForTransactionRequest\x12<\n\x08\x63ommands\x18\x01 \x01(\x0b\x32 .com.daml.ledger.api.v2.CommandsR\x08\x63ommands\x12X\n\x12transaction_format\x18\x02 \x01(\x0b\x32).com.daml.ledger.api.v2.TransactionFormatR\x11transactionFormat\"a\n\x15SubmitAndWaitResponse\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12+\n\x11\x63ompletion_offset\x18\x02 \x01(\x03R\x10\x63ompletionOffset\"l\n#SubmitAndWaitForTransactionResponse\x12\x45\n\x0btransaction\x18\x01 \x01(\x0b\x32#.com.daml.ledger.api.v2.TransactionR\x0btransaction\"\xd0\x01\n#SubmitAndWaitForReassignmentRequest\x12\x61\n\x15reassignment_commands\x18\x01 \x01(\x0b\x32,.com.daml.ledger.api.v2.ReassignmentCommandsR\x14reassignmentCommands\x12\x46\n\x0c\x65vent_format\x18\x02 \x01(\x0b\x32#.com.daml.ledger.api.v2.EventFormatR\x0b\x65ventFormat\"p\n$SubmitAndWaitForReassignmentResponse\x12H\n\x0creassignment\x18\x01 \x01(\x0b\x32$.com.daml.ledger.api.v2.ReassignmentR\x0creassignment2\xb3\x03\n\x0e\x43ommandService\x12l\n\rSubmitAndWait\x12,.com.daml.ledger.api.v2.SubmitAndWaitRequest\x1a-.com.daml.ledger.api.v2.SubmitAndWaitResponse\x12\x96\x01\n\x1bSubmitAndWaitForTransaction\x12:.com.daml.ledger.api.v2.SubmitAndWaitForTransactionRequest\x1a;.com.daml.ledger.api.v2.SubmitAndWaitForTransactionResponse\x12\x99\x01\n\x1cSubmitAndWaitForReassignment\x12;.com.daml.ledger.api.v2.SubmitAndWaitForReassignmentRequest\x1a<.com.daml.ledger.api.v2.SubmitAndWaitForReassignmentResponseB\x92\x01\n\x16\x63om.daml.ledger.api.v2B\x18\x43ommandServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.command_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\030CommandServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_SUBMITANDWAITREQUEST']._serialized_start=297
  _globals['_SUBMITANDWAITREQUEST']._serialized_end=381
  _globals['_SUBMITANDWAITFORTRANSACTIONREQUEST']._serialized_start=384
  _globals['_SUBMITANDWAITFORTRANSACTIONREQUEST']._serialized_end=572
  _globals['_SUBMITANDWAITRESPONSE']._serialized_start=574
  _globals['_SUBMITANDWAITRESPONSE']._serialized_end=671
  _globals['_SUBMITANDWAITFORTRANSACTIONRESPONSE']._serialized_start=673
  _globals['_SUBMITANDWAITFORTRANSACTIONRESPONSE']._serialized_end=781
  _globals['_SUBMITANDWAITFORREASSIGNMENTREQUEST']._serialized_start=784
  _globals['_SUBMITANDWAITFORREASSIGNMENTREQUEST']._serialized_end=992
  _globals['_SUBMITANDWAITFORREASSIGNMENTRESPONSE']._serialized_start=994
  _globals['_SUBMITANDWAITFORREASSIGNMENTRESPONSE']._serialized_end=1106
  _globals['_COMMANDSERVICE']._serialized_start=1109
  _globals['_COMMANDSERVICE']._serialized_end=1544
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/admin/v30/sequencer_pruning_administration_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/sequencer/admin/v30/sequencer_pruning_administration_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....admin.pruning.v30 import pruning_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nZcom/digitalasset/canton/sequencer/admin/v30/sequencer_pruning_administration_service.proto\x12+com.digitalasset.canton.sequencer.admin.v30\x1a\x37\x63om/digitalasset/canton/admin/pruning/v30/pruning.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"H\n\x0cPruneRequest\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\")\n\rPruneResponse\x12\x18\n\x07\x64\x65tails\x18\x01 \x01(\tR\x07\x64\x65tails2\xb1\t\n%SequencerPruningAdministrationService\x12~\n\x05Prune\x12\x39.com.digitalasset.canton.sequencer.admin.v30.PruneRequest\x1a:.com.digitalasset.canton.sequencer.admin.v30.PruneResponse\x12\x8c\x01\n\x0bSetSchedule\x12=.com.digitalasset.canton.admin.pruning.v30.SetScheduleRequest\x1a>.com.digitalasset.canton.admin.pruning.v30.SetScheduleResponse\x12\x80\x01\n\x07SetCron\x12\x39.com.digitalasset.canton.admin.pruning.v30.SetCronRequest\x1a:.com.digitalasset.canton.admin.pruning.v30.SetCronResponse\x12\x95\x01\n\x0eSetMaxDuration\x12@.com.digitalasset.canton.admin.pruning.v30.SetMaxDurationRequest\x1a\x41.com.digitalasset.canton.admin.pruning.v30.SetMaxDurationResponse\x12\x8f\x01\n\x0cSetRetention\x12>.com.digitalasset.canton.admin.pruning.v30.SetRetentionRequest\x1a?.com.digitalasset.canton.admin.pruning.v30.SetRetentionResponse\x12\x92\x01\n\rClearSchedule\x12?.com.digitalasset.canton.admin.pruning.v30.ClearScheduleRequest\x1a@.com.digitalasset.canton.admin.pruning.v30.ClearScheduleResponse\x12\x8c\x01\n\x0bGetSchedule\x12=.com.digitalasset.canton.admin.pruning.v30.GetScheduleRequest\x1a>.com.digitalasset.canton.admin.pruning.v30.GetScheduleResponse\x12\xa7\x01\n\x14\x46indPruningTimestamp\x12\x46.com.digitalasset.canton.admin.pruning.v30.FindPruningTimestampRequest\x1aG.com.digitalasset.canton.admin.pruning.v30.FindPruningTimestampResponseB\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.admin.v30.sequencer_pruning_administration_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30'
  _globals['_PRUNEREQUEST']._serialized_start=229
  _globals['_PRUNEREQUEST']._serialized_end=301
  _globals['_PRUNERESPONSE']._serialized_start=303
  _globals['_PRUNERESPONSE']._serialized_end=344
  _globals['_SEQUENCERPRUNINGADMINISTRATIONSERVICE']._serialized_start=347
  _globals['_SEQUENCERPRUNINGADMINISTRATIONSERVICE']._serialized_end=1548
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from typing import NamedTuple, Optional

__all__ = ["SdkVersion"]


class SdkVersion(NamedTuple):
    """Helper for parsing SDK version strings."""

    major: int
    minor: int
    patch: int

    @classmethod
    def parse(cls, s: Optional[str]) -> Optional[SdkVersion]:
        """
        Parse version string like '2.10.3' or 'v3.4.10'.

        Args:
            s: Version string to parse (can be None)

        Returns:
            Parsed SdkVersion or None if invalid/None
        """
        if s is None:
            return None
        s = s.strip()
        if s.startswith("v"):
            s = s[1:]
        if "-" in s:
            s = s[: s.index("-")]
        try:
            parts = s.split(".")
            nums = [int(p) for p in parts]
            while len(nums) < 3:
                nums.append(0)
            return cls(nums[0], nums[1], nums[2])
        except (ValueError, IndexError):
            return None

    def __str__(self) -> str:
        return f"{self.major}.{self.minor}.{self.patch}"



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from http import HTTPStatus
from typing import Any

import httpx

from ...client import AuthenticatedClient, Client
from ...models.js_canton_error import JsCantonError
from ...models.list_users_response import ListUsersResponse
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    page_size: int | Unset = UNSET,
    page_token: str | Unset = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["pageSize"] = page_size

    params["pageToken"] = page_token

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/v2/users",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> JsCantonError | ListUsersResponse | str:
    if response.status_code == 200:
        response_200 = ListUsersResponse.from_dict(response.json())

        return response_200

    if response.status_code == 400:
        response_400 = response.text
        return response_400

    response_default = JsCantonError.from_dict(response.json())

    return response_default


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[JsCantonError | ListUsersResponse | str]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    page_size: int | Unset = UNSET,
    page_token: str | Unset = UNSET,
) -> Response[JsCantonError | ListUsersResponse | str]:
    """List all users.

    Args:
        page_size (int | Unset):
        page_token (str | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[JsCantonError | ListUsersResponse | str]
    """

    kwargs = _get_kwargs(
        page_size=page_size,
        page_token=page_token,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    page_size: int | Unset = UNSET,
    page_token: str | Unset = UNSET,
) -> JsCantonError | ListUsersResponse | str | None:
    """List all users.

    Args:
        page_size (int | Unset):
        page_token (str | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        JsCantonError | ListUsersResponse | str
    """

    return sync_detailed(
        client=client,
        page_size=page_size,
        page_token=page_token,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    page_size: int | Unset = UNSET,
    page_token: str | Unset = UNSET,
) -> Response[JsCantonError | ListUsersResponse | str]:
    """List all users.

    Args:
        page_size (int | Unset):
        page_token (str | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[JsCantonError | ListUsersResponse | str]
    """

    kwargs = _get_kwargs(
        page_size=page_size,
        page_token=page_token,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    page_size: int | Unset = UNSET,
    page_token: str | Unset = UNSET,
) -> JsCantonError | ListUsersResponse | str | None:
    """List all users.

    Args:
        page_size (int | Unset):
        page_token (str | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        JsCantonError | ListUsersResponse | str
    """

    return (
        await asyncio_detailed(
            client=client,
            page_size=page_size,
            page_token=page_token,
        )
    ).parsed



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....protocol.v30 import participant_transaction_pb2 as _participant_transaction_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CompletionInfo(_message.Message):
    __slots__ = ("act_as", "user_id", "command_id", "opt_deduplication_period", "submission_id")
    ACT_AS_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    COMMAND_ID_FIELD_NUMBER: _ClassVar[int]
    OPT_DEDUPLICATION_PERIOD_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    act_as: _containers.RepeatedScalarFieldContainer[str]
    user_id: str
    command_id: str
    opt_deduplication_period: _participant_transaction_pb2.DeduplicationPeriod
    submission_id: str
    def __init__(self, act_as: _Optional[_Iterable[str]] = ..., user_id: _Optional[str] = ..., command_id: _Optional[str] = ..., opt_deduplication_period: _Optional[_Union[_participant_transaction_pb2.DeduplicationPeriod, _Mapping]] = ..., submission_id: _Optional[str] = ...) -> None: ...

class CommandRejected(_message.Message):
    __slots__ = ()
    class GrpcRejectionReasonTemplate(_message.Message):
        __slots__ = ("status",)
        STATUS_FIELD_NUMBER: _ClassVar[int]
        status: bytes
        def __init__(self, status: _Optional[bytes] = ...) -> None: ...
    def __init__(self) -> None: ...

class SubmissionTrackingData(_message.Message):
    __slots__ = ("transaction",)
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    transaction: TransactionSubmissionTrackingData
    def __init__(self, transaction: _Optional[_Union[TransactionSubmissionTrackingData, _Mapping]] = ...) -> None: ...

class TransactionSubmissionTrackingData(_message.Message):
    __slots__ = ("completion_info", "rejection_cause", "physical_synchronizer_id")
    class RejectionCause(_message.Message):
        __slots__ = ("timeout", "rejection_reason_template")
        TIMEOUT_FIELD_NUMBER: _ClassVar[int]
        REJECTION_REASON_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
        timeout: _empty_pb2.Empty
        rejection_reason_template: CommandRejected.GrpcRejectionReasonTemplate
        def __init__(self, timeout: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ..., rejection_reason_template: _Optional[_Union[CommandRejected.GrpcRejectionReasonTemplate, _Mapping]] = ...) -> None: ...
    COMPLETION_INFO_FIELD_NUMBER: _ClassVar[int]
    REJECTION_CAUSE_FIELD_NUMBER: _ClassVar[int]
    PHYSICAL_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    completion_info: CompletionInfo
    rejection_cause: TransactionSubmissionTrackingData.RejectionCause
    physical_synchronizer_id: str
    def __init__(self, completion_info: _Optional[_Union[CompletionInfo, _Mapping]] = ..., rejection_cause: _Optional[_Union[TransactionSubmissionTrackingData.RejectionCause, _Mapping]] = ..., physical_synchronizer_id: _Optional[str] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.unknown_field_set import UnknownFieldSet


T = TypeVar("T", bound="FieldMask")


@_attrs_define
class FieldMask:
    """
    Attributes:
        unknown_fields (UnknownFieldSet):
        paths (list[str] | Unset):
    """

    unknown_fields: UnknownFieldSet
    paths: list[str] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        unknown_fields = self.unknown_fields.to_dict()

        paths: list[str] | Unset = UNSET
        if not isinstance(self.paths, Unset):
            paths = self.paths

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "unknownFields": unknown_fields,
            }
        )
        if paths is not UNSET:
            field_dict["paths"] = paths

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.unknown_field_set import UnknownFieldSet

        d = dict(src_dict)
        unknown_fields = UnknownFieldSet.from_dict(d.pop("unknownFields"))

        paths = cast(list[str], d.pop("paths", UNSET))

        field_mask = cls(
            unknown_fields=unknown_fields,
            paths=paths,
        )

        field_mask.additional_properties = d
        return field_mask

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import pruning_service_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_pruning__service__pb2
from ...pruning.v30 import pruning_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in com/digitalasset/canton/admin/participant/v30/pruning_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class PruningServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Prune = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PruningService/Prune',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_pruning__service__pb2.PruneRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_pruning__service__pb2.PruneResponse.FromString,
                _registered_method=True)
        self.GetSafePruningOffset = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PruningService/GetSafePruningOffset',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_pruning__service__pb2.GetSafePruningOffsetRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_pruning__service__pb2.GetSafePruningOffsetResponse.FromString,
                _registered_method=True)
        self.SetSchedule = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PruningService/SetSchedule',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetScheduleRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetScheduleResponse.FromString,
                _registered_method=True)
        self.SetParticipantSchedule = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PruningService/SetParticipantSchedule',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetParticipantScheduleRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetParticipantScheduleResponse.FromString,
                _registered_method=True)
        self.SetCron = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PruningService/SetCron',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetCronRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetCronResponse.FromString,
                _registered_method=True)
        self.SetMaxDuration = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PruningService/SetMaxDuration',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetMaxDurationRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetMaxDurationResponse.FromString,
                _registered_method=True)
        self.SetRetention = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PruningService/SetRetention',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetRetentionRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetRetentionResponse.FromString,
                _registered_method=True)
        self.ClearSchedule = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PruningService/ClearSchedule',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.ClearScheduleRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.ClearScheduleResponse.FromString,
                _registered_method=True)
        self.GetSchedule = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PruningService/GetSchedule',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetScheduleRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetScheduleResponse.FromString,
                _registered_method=True)
        self.GetParticipantSchedule = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PruningService/GetParticipantSchedule',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetParticipantScheduleRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetParticipantScheduleResponse.FromString,
                _registered_method=True)
        self.SetNoWaitCommitmentsFrom = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PruningService/SetNoWaitCommitmentsFrom',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetNoWaitCommitmentsFromRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetNoWaitCommitmentsFromResponse.FromString,
                _registered_method=True)
        self.ResetNoWaitCommitmentsFrom = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PruningService/ResetNoWaitCommitmentsFrom',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.ResetNoWaitCommitmentsFromRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.ResetNoWaitCommitmentsFromResponse.FromString,
                _registered_method=True)
        self.GetNoWaitCommitmentsFrom = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PruningService/GetNoWaitCommitmentsFrom',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetNoWaitCommitmentsFromRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetNoWaitCommitmentsFromResponse.FromString,
                _registered_method=True)


class PruningServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Prune(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSafePruningOffset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSchedule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetParticipantSchedule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetCron(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetMaxDuration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRetention(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearSchedule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSchedule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetParticipantSchedule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetNoWaitCommitmentsFrom(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetNoWaitCommitmentsFrom(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNoWaitCommitmentsFrom(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PruningServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Prune': grpc.unary_unary_rpc_method_handler(
                    servicer.Prune,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_pruning__service__pb2.PruneRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_pruning__service__pb2.PruneResponse.SerializeToString,
            ),
            'GetSafePruningOffset': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSafePruningOffset,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_pruning__service__pb2.GetSafePruningOffsetRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_pruning__service__pb2.GetSafePruningOffsetResponse.SerializeToString,
            ),
            'SetSchedule': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSchedule,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetScheduleRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetScheduleResponse.SerializeToString,
            ),
            'SetParticipantSchedule': grpc.unary_unary_rpc_method_handler(
                    servicer.SetParticipantSchedule,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetParticipantScheduleRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetParticipantScheduleResponse.SerializeToString,
            ),
            'SetCron': grpc.unary_unary_rpc_method_handler(
                    servicer.SetCron,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetCronRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetCronResponse.SerializeToString,
            ),
            'SetMaxDuration': grpc.unary_unary_rpc_method_handler(
                    servicer.SetMaxDuration,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetMaxDurationRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetMaxDurationResponse.SerializeToString,
            ),
            'SetRetention': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRetention,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetRetentionRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetRetentionResponse.SerializeToString,
            ),
            'ClearSchedule': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearSchedule,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.ClearScheduleRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.ClearScheduleResponse.SerializeToString,
            ),
            'GetSchedule': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSchedule,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetScheduleRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetScheduleResponse.SerializeToString,
            ),
            'GetParticipantSchedule': grpc.unary_unary_rpc_method_handler(
                    servicer.GetParticipantSchedule,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetParticipantScheduleRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetParticipantScheduleResponse.SerializeToString,
            ),
            'SetNoWaitCommitmentsFrom': grpc.unary_unary_rpc_method_handler(
                    servicer.SetNoWaitCommitmentsFrom,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetNoWaitCommitmentsFromRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetNoWaitCommitmentsFromResponse.SerializeToString,
            ),
            'ResetNoWaitCommitmentsFrom': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetNoWaitCommitmentsFrom,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.ResetNoWaitCommitmentsFromRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.ResetNoWaitCommitmentsFromResponse.SerializeToString,
            ),
            'GetNoWaitCommitmentsFrom': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNoWaitCommitmentsFrom,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetNoWaitCommitmentsFromRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetNoWaitCommitmentsFromResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.digitalasset.canton.admin.participant.v30.PruningService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.digitalasset.canton.admin.participant.v30.PruningService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class PruningService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Prune(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PruningService/Prune',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_pruning__service__pb2.PruneRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_pruning__service__pb2.PruneResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSafePruningOffset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PruningService/GetSafePruningOffset',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_pruning__service__pb2.GetSafePruningOffsetRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_pruning__service__pb2.GetSafePruningOffsetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetSchedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PruningService/SetSchedule',
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetScheduleRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetScheduleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetParticipantSchedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PruningService/SetParticipantSchedule',
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetParticipantScheduleRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetParticipantScheduleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetCron(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PruningService/SetCron',
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetCronRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetCronResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetMaxDuration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PruningService/SetMaxDuration',
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetMaxDurationRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetMaxDurationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetRetention(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PruningService/SetRetention',
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetRetentionRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetRetentionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ClearSchedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PruningService/ClearSchedule',
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.ClearScheduleRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.ClearScheduleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSchedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PruningService/GetSchedule',
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetScheduleRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetScheduleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetParticipantSchedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PruningService/GetParticipantSchedule',
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetParticipantScheduleRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetParticipantScheduleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetNoWaitCommitmentsFrom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PruningService/SetNoWaitCommitmentsFrom',
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetNoWaitCommitmentsFromRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetNoWaitCommitmentsFromResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ResetNoWaitCommitmentsFrom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PruningService/ResetNoWaitCommitmentsFrom',
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.ResetNoWaitCommitmentsFromRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.ResetNoWaitCommitmentsFromResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetNoWaitCommitmentsFrom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PruningService/GetNoWaitCommitmentsFrom',
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetNoWaitCommitmentsFromRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetNoWaitCommitmentsFromResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from typing import Optional

from ..util.version import SdkVersion
from . import daml_lf_1 as lf
from .parse_factory.pb_parse_base import ProtobufParserBase
from .parse_factory.pb_v1 import ProtobufParser117
from .parse_factory.pb_v2 import ProtobufParser21

__all__ = ["ProtobufParserFactory", "UnsupportedVersionError"]


class UnsupportedVersionError(Exception):
    """Raised when an unsupported DAML-LF version is encountered."""

    pass


class ProtobufParserFactory:
    """
    Factory for creating DAML-LF protobuf parsers based on version.

    Supports:
    - DAML-LF 1.x or DAML-LF 2.x (via ProtobufParser117)
    - DAML-LF 3.x (via ProtobufParser21)

    The factory uses lazy loading to avoid circular imports and unnecessary
    module loading overhead.
    """

    @classmethod
    def create_parser(
        cls, package_id: lf.PackageRef, sdk_version: Optional[str]
    ) -> ProtobufParserBase:
        """
        Create a parser for the specified DAML-LF version.

        Args:
            package_id: The package ID being parsed
            version: Version string (e.g., "1.17", "2.1", "3.3)

        Returns:
            Version-specific parser instance

        Raises:
            UnsupportedVersionError: If version is not supported
        """

        version = SdkVersion.parse(sdk_version)
        if version is None:
            # Default to DAML-LF 1.17 (SDK 2.10) for Canton 2.x compatibility
            return ProtobufParser117(package_id)

        if version.major == 1 or version.major == 0 or version.major == 2:
            return ProtobufParser117(package_id)
        elif version.major == 3:
            return ProtobufParser21(package_id)

        # default to old parser for unknown versions
        return ProtobufParser117(package_id)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from . import acs_import_pb2 as _acs_import_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ParticipantPermission(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PARTICIPANT_PERMISSION_UNSPECIFIED: _ClassVar[ParticipantPermission]
    PARTICIPANT_PERMISSION_SUBMISSION: _ClassVar[ParticipantPermission]
    PARTICIPANT_PERMISSION_CONFIRMATION: _ClassVar[ParticipantPermission]
    PARTICIPANT_PERMISSION_OBSERVATION: _ClassVar[ParticipantPermission]
PARTICIPANT_PERMISSION_UNSPECIFIED: ParticipantPermission
PARTICIPANT_PERMISSION_SUBMISSION: ParticipantPermission
PARTICIPANT_PERMISSION_CONFIRMATION: ParticipantPermission
PARTICIPANT_PERMISSION_OBSERVATION: ParticipantPermission

class AddPartyAsyncRequest(_message.Message):
    __slots__ = ("party_id", "synchronizer_id", "source_participant_uid", "topology_serial", "participant_permission")
    PARTY_ID_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    TOPOLOGY_SERIAL_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_PERMISSION_FIELD_NUMBER: _ClassVar[int]
    party_id: str
    synchronizer_id: str
    source_participant_uid: str
    topology_serial: int
    participant_permission: ParticipantPermission
    def __init__(self, party_id: _Optional[str] = ..., synchronizer_id: _Optional[str] = ..., source_participant_uid: _Optional[str] = ..., topology_serial: _Optional[int] = ..., participant_permission: _Optional[_Union[ParticipantPermission, str]] = ...) -> None: ...

class AddPartyAsyncResponse(_message.Message):
    __slots__ = ("add_party_request_id",)
    ADD_PARTY_REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    add_party_request_id: str
    def __init__(self, add_party_request_id: _Optional[str] = ...) -> None: ...

class GetAddPartyStatusRequest(_message.Message):
    __slots__ = ("add_party_request_id",)
    ADD_PARTY_REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    add_party_request_id: str
    def __init__(self, add_party_request_id: _Optional[str] = ...) -> None: ...

class GetAddPartyStatusResponse(_message.Message):
    __slots__ = ("party_id", "synchronizer_id", "source_participant_uid", "target_participant_uid", "topology_serial", "participant_permission", "status")
    class Status(_message.Message):
        __slots__ = ("proposal_processed", "agreement_accepted", "topology_authorized", "connection_established", "replicating_acs", "fully_replicated_acs", "completed", "error", "disconnected")
        class ProposalProcessed(_message.Message):
            __slots__ = ()
            def __init__(self) -> None: ...
        class AgreementAccepted(_message.Message):
            __slots__ = ("sequencer_uid",)
            SEQUENCER_UID_FIELD_NUMBER: _ClassVar[int]
            sequencer_uid: str
            def __init__(self, sequencer_uid: _Optional[str] = ...) -> None: ...
        class TopologyAuthorized(_message.Message):
            __slots__ = ("sequencer_uid", "timestamp")
            SEQUENCER_UID_FIELD_NUMBER: _ClassVar[int]
            TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
            sequencer_uid: str
            timestamp: _timestamp_pb2.Timestamp
            def __init__(self, sequencer_uid: _Optional[str] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
        class ConnectionEstablished(_message.Message):
            __slots__ = ("sequencer_uid", "timestamp")
            SEQUENCER_UID_FIELD_NUMBER: _ClassVar[int]
            TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
            sequencer_uid: str
            timestamp: _timestamp_pb2.Timestamp
            def __init__(self, sequencer_uid: _Optional[str] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
        class ReplicatingAcs(_message.Message):
            __slots__ = ("sequencer_uid", "timestamp", "contracts_replicated")
            SEQUENCER_UID_FIELD_NUMBER: _ClassVar[int]
            TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
            CONTRACTS_REPLICATED_FIELD_NUMBER: _ClassVar[int]
            sequencer_uid: str
            timestamp: _timestamp_pb2.Timestamp
            contracts_replicated: int
            def __init__(self, sequencer_uid: _Optional[str] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., contracts_replicated: _Optional[int] = ...) -> None: ...
        class FullyReplicatedAcs(_message.Message):
            __slots__ = ("sequencer_uid", "timestamp", "contracts_replicated")
            SEQUENCER_UID_FIELD_NUMBER: _ClassVar[int]
            TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
            CONTRACTS_REPLICATED_FIELD_NUMBER: _ClassVar[int]
            sequencer_uid: str
            timestamp: _timestamp_pb2.Timestamp
            contracts_replicated: int
            def __init__(self, sequencer_uid: _Optional[str] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., contracts_replicated: _Optional[int] = ...) -> None: ...
        class Completed(_message.Message):
            __slots__ = ("sequencer_uid", "timestamp", "contracts_replicated")
            SEQUENCER_UID_FIELD_NUMBER: _ClassVar[int]
            TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
            CONTRACTS_REPLICATED_FIELD_NUMBER: _ClassVar[int]
            sequencer_uid: str
            timestamp: _timestamp_pb2.Timestamp
            contracts_replicated: int
            def __init__(self, sequencer_uid: _Optional[str] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., contracts_replicated: _Optional[int] = ...) -> None: ...
        class Error(_message.Message):
            __slots__ = ("error_message", "status_prior_to_error")
            ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
            STATUS_PRIOR_TO_ERROR_FIELD_NUMBER: _ClassVar[int]
            error_message: str
            status_prior_to_error: GetAddPartyStatusResponse.Status
            def __init__(self, error_message: _Optional[str] = ..., status_prior_to_error: _Optional[_Union[GetAddPartyStatusResponse.Status, _Mapping]] = ...) -> None: ...
        class Disconnected(_message.Message):
            __slots__ = ("disconnect_message", "status_prior_to_disconnect")
            DISCONNECT_MESSAGE_FIELD_NUMBER: _ClassVar[int]
            STATUS_PRIOR_TO_DISCONNECT_FIELD_NUMBER: _ClassVar[int]
            disconnect_message: str
            status_prior_to_disconnect: GetAddPartyStatusResponse.Status
            def __init__(self, disconnect_message: _Optional[str] = ..., status_prior_to_disconnect: _Optional[_Union[GetAddPartyStatusResponse.Status, _Mapping]] = ...) -> None: ...
        PROPOSAL_PROCESSED_FIELD_NUMBER: _ClassVar[int]
        AGREEMENT_ACCEPTED_FIELD_NUMBER: _ClassVar[int]
        TOPOLOGY_AUTHORIZED_FIELD_NUMBER: _ClassVar[int]
        CONNECTION_ESTABLISHED_FIELD_NUMBER: _ClassVar[int]
        REPLICATING_ACS_FIELD_NUMBER: _ClassVar[int]
        FULLY_REPLICATED_ACS_FIELD_NUMBER: _ClassVar[int]
        COMPLETED_FIELD_NUMBER: _ClassVar[int]
        ERROR_FIELD_NUMBER: _ClassVar[int]
        DISCONNECTED_FIELD_NUMBER: _ClassVar[int]
        proposal_processed: GetAddPartyStatusResponse.Status.ProposalProcessed
        agreement_accepted: GetAddPartyStatusResponse.Status.AgreementAccepted
        topology_authorized: GetAddPartyStatusResponse.Status.TopologyAuthorized
        connection_established: GetAddPartyStatusResponse.Status.ConnectionEstablished
        replicating_acs: GetAddPartyStatusResponse.Status.ReplicatingAcs
        fully_replicated_acs: GetAddPartyStatusResponse.Status.FullyReplicatedAcs
        completed: GetAddPartyStatusResponse.Status.Completed
        error: GetAddPartyStatusResponse.Status.Error
        disconnected: GetAddPartyStatusResponse.Status.Disconnected
        def __init__(self, proposal_processed: _Optional[_Union[GetAddPartyStatusResponse.Status.ProposalProcessed, _Mapping]] = ..., agreement_accepted: _Optional[_Union[GetAddPartyStatusResponse.Status.AgreementAccepted, _Mapping]] = ..., topology_authorized: _Optional[_Union[GetAddPartyStatusResponse.Status.TopologyAuthorized, _Mapping]] = ..., connection_established: _Optional[_Union[GetAddPartyStatusResponse.Status.ConnectionEstablished, _Mapping]] = ..., replicating_acs: _Optional[_Union[GetAddPartyStatusResponse.Status.ReplicatingAcs, _Mapping]] = ..., fully_replicated_acs: _Optional[_Union[GetAddPartyStatusResponse.Status.FullyReplicatedAcs, _Mapping]] = ..., completed: _Optional[_Union[GetAddPartyStatusResponse.Status.Completed, _Mapping]] = ..., error: _Optional[_Union[GetAddPartyStatusResponse.Status.Error, _Mapping]] = ..., disconnected: _Optional[_Union[GetAddPartyStatusResponse.Status.Disconnected, _Mapping]] = ...) -> None: ...
    PARTY_ID_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    TARGET_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    TOPOLOGY_SERIAL_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_PERMISSION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    party_id: str
    synchronizer_id: str
    source_participant_uid: str
    target_participant_uid: str
    topology_serial: int
    participant_permission: ParticipantPermission
    status: GetAddPartyStatusResponse.Status
    def __init__(self, party_id: _Optional[str] = ..., synchronizer_id: _Optional[str] = ..., source_participant_uid: _Optional[str] = ..., target_participant_uid: _Optional[str] = ..., topology_serial: _Optional[int] = ..., participant_permission: _Optional[_Union[ParticipantPermission, str]] = ..., status: _Optional[_Union[GetAddPartyStatusResponse.Status, _Mapping]] = ...) -> None: ...

class ExportPartyAcsRequest(_message.Message):
    __slots__ = ("party_id", "synchronizer_id", "target_participant_uid", "begin_offset_exclusive", "wait_for_activation_timeout")
    PARTY_ID_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    BEGIN_OFFSET_EXCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    WAIT_FOR_ACTIVATION_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    party_id: str
    synchronizer_id: str
    target_participant_uid: str
    begin_offset_exclusive: int
    wait_for_activation_timeout: _duration_pb2.Duration
    def __init__(self, party_id: _Optional[str] = ..., synchronizer_id: _Optional[str] = ..., target_participant_uid: _Optional[str] = ..., begin_offset_exclusive: _Optional[int] = ..., wait_for_activation_timeout: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class ExportPartyAcsResponse(_message.Message):
    __slots__ = ("chunk",)
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    chunk: bytes
    def __init__(self, chunk: _Optional[bytes] = ...) -> None: ...

class ImportPartyAcsRequest(_message.Message):
    __slots__ = ("acs_snapshot", "workflow_id_prefix", "contract_import_mode", "representative_package_id_override")
    ACS_SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_PREFIX_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_IMPORT_MODE_FIELD_NUMBER: _ClassVar[int]
    REPRESENTATIVE_PACKAGE_ID_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    acs_snapshot: bytes
    workflow_id_prefix: str
    contract_import_mode: _acs_import_pb2.ContractImportMode
    representative_package_id_override: _acs_import_pb2.RepresentativePackageIdOverride
    def __init__(self, acs_snapshot: _Optional[bytes] = ..., workflow_id_prefix: _Optional[str] = ..., contract_import_mode: _Optional[_Union[_acs_import_pb2.ContractImportMode, str]] = ..., representative_package_id_override: _Optional[_Union[_acs_import_pb2.RepresentativePackageIdOverride, _Mapping]] = ...) -> None: ...

class ImportPartyAcsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetHighestOffsetByTimestampRequest(_message.Message):
    __slots__ = ("synchronizer_id", "timestamp", "force")
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    FORCE_FIELD_NUMBER: _ClassVar[int]
    synchronizer_id: str
    timestamp: _timestamp_pb2.Timestamp
    force: bool
    def __init__(self, synchronizer_id: _Optional[str] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., force: bool = ...) -> None: ...

class GetHighestOffsetByTimestampResponse(_message.Message):
    __slots__ = ("ledger_offset",)
    LEDGER_OFFSET_FIELD_NUMBER: _ClassVar[int]
    ledger_offset: int
    def __init__(self, ledger_offset: _Optional[int] = ...) -> None: ...

class ClearPartyOnboardingFlagRequest(_message.Message):
    __slots__ = ("party_id", "synchronizer_id", "begin_offset_exclusive", "wait_for_activation_timeout")
    PARTY_ID_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    BEGIN_OFFSET_EXCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    WAIT_FOR_ACTIVATION_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    party_id: str
    synchronizer_id: str
    begin_offset_exclusive: int
    wait_for_activation_timeout: _duration_pb2.Duration
    def __init__(self, party_id: _Optional[str] = ..., synchronizer_id: _Optional[str] = ..., begin_offset_exclusive: _Optional[int] = ..., wait_for_activation_timeout: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class ClearPartyOnboardingFlagResponse(_message.Message):
    __slots__ = ("onboarded", "earliest_retry_timestamp")
    ONBOARDED_FIELD_NUMBER: _ClassVar[int]
    EARLIEST_RETRY_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    onboarded: bool
    earliest_retry_timestamp: _timestamp_pb2.Timestamp
    def __init__(self, onboarded: bool = ..., earliest_retry_timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union
from builtins import bytes as _bytes

DESCRIPTOR: _descriptor.FileDescriptor

class ListPackagesRequest(_message.Message):
    __slots__ = ("limit", "filter_name")
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    FILTER_NAME_FIELD_NUMBER: _ClassVar[int]
    limit: int
    filter_name: str
    def __init__(self, limit: _Optional[int] = ..., filter_name: _Optional[str] = ...) -> None: ...

class PackageDescription(_message.Message):
    __slots__ = ("package_id", "name", "version", "uploaded_at", "size")
    PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    UPLOADED_AT_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    package_id: str
    name: str
    version: str
    uploaded_at: _timestamp_pb2.Timestamp
    size: int
    def __init__(self, package_id: _Optional[str] = ..., name: _Optional[str] = ..., version: _Optional[str] = ..., uploaded_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., size: _Optional[int] = ...) -> None: ...

class ListPackagesResponse(_message.Message):
    __slots__ = ("package_descriptions",)
    PACKAGE_DESCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    package_descriptions: _containers.RepeatedCompositeFieldContainer[PackageDescription]
    def __init__(self, package_descriptions: _Optional[_Iterable[_Union[PackageDescription, _Mapping]]] = ...) -> None: ...

class GetPackageContentsRequest(_message.Message):
    __slots__ = ("package_id",)
    PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    package_id: str
    def __init__(self, package_id: _Optional[str] = ...) -> None: ...

class ModuleDescription(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class GetPackageContentsResponse(_message.Message):
    __slots__ = ("description", "modules", "is_utility_package", "language_version")
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    MODULES_FIELD_NUMBER: _ClassVar[int]
    IS_UTILITY_PACKAGE_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_VERSION_FIELD_NUMBER: _ClassVar[int]
    description: PackageDescription
    modules: _containers.RepeatedCompositeFieldContainer[ModuleDescription]
    is_utility_package: bool
    language_version: str
    def __init__(self, description: _Optional[_Union[PackageDescription, _Mapping]] = ..., modules: _Optional[_Iterable[_Union[ModuleDescription, _Mapping]]] = ..., is_utility_package: bool = ..., language_version: _Optional[str] = ...) -> None: ...

class GetPackageReferencesRequest(_message.Message):
    __slots__ = ("package_id",)
    PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    package_id: str
    def __init__(self, package_id: _Optional[str] = ...) -> None: ...

class GetPackageReferencesResponse(_message.Message):
    __slots__ = ("dars",)
    DARS_FIELD_NUMBER: _ClassVar[int]
    dars: _containers.RepeatedCompositeFieldContainer[DarDescription]
    def __init__(self, dars: _Optional[_Iterable[_Union[DarDescription, _Mapping]]] = ...) -> None: ...

class RemovePackageRequest(_message.Message):
    __slots__ = ("package_id", "force")
    PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    FORCE_FIELD_NUMBER: _ClassVar[int]
    package_id: str
    force: bool
    def __init__(self, package_id: _Optional[str] = ..., force: bool = ...) -> None: ...

class RemovePackageResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: _empty_pb2.Empty
    def __init__(self, success: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ...) -> None: ...

class ValidateDarRequest(_message.Message):
    __slots__ = ("data", "filename", "synchronizer_id")
    DATA_FIELD_NUMBER: _ClassVar[int]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    filename: str
    synchronizer_id: str
    def __init__(self, data: _Optional[bytes] = ..., filename: _Optional[str] = ..., synchronizer_id: _Optional[str] = ...) -> None: ...

class ValidateDarResponse(_message.Message):
    __slots__ = ("main_package_id",)
    MAIN_PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    main_package_id: str
    def __init__(self, main_package_id: _Optional[str] = ...) -> None: ...

class UploadDarRequest(_message.Message):
    __slots__ = ("dars", "vet_all_packages", "synchronize_vetting", "synchronizer_id")
    class UploadDarData(_message.Message):
        __slots__ = ("bytes", "description", "expected_main_package_id")
        BYTES_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        EXPECTED_MAIN_PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
        bytes: bytes
        description: str
        expected_main_package_id: str
        def __init__(self, bytes: _Optional[_bytes] = ..., description: _Optional[str] = ..., expected_main_package_id: _Optional[str] = ...) -> None: ...
    DARS_FIELD_NUMBER: _ClassVar[int]
    VET_ALL_PACKAGES_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZE_VETTING_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    dars: _containers.RepeatedCompositeFieldContainer[UploadDarRequest.UploadDarData]
    vet_all_packages: bool
    synchronize_vetting: bool
    synchronizer_id: str
    def __init__(self, dars: _Optional[_Iterable[_Union[UploadDarRequest.UploadDarData, _Mapping]]] = ..., vet_all_packages: bool = ..., synchronize_vetting: bool = ..., synchronizer_id: _Optional[str] = ...) -> None: ...

class UploadDarResponse(_message.Message):
    __slots__ = ("dar_ids",)
    DAR_IDS_FIELD_NUMBER: _ClassVar[int]
    dar_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, dar_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class RemoveDarRequest(_message.Message):
    __slots__ = ("main_package_id",)
    MAIN_PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    main_package_id: str
    def __init__(self, main_package_id: _Optional[str] = ...) -> None: ...

class RemoveDarResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetDarRequest(_message.Message):
    __slots__ = ("main_package_id",)
    MAIN_PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    main_package_id: str
    def __init__(self, main_package_id: _Optional[str] = ...) -> None: ...

class DarDescription(_message.Message):
    __slots__ = ("main", "name", "version", "description")
    MAIN_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    main: str
    name: str
    version: str
    description: str
    def __init__(self, main: _Optional[str] = ..., name: _Optional[str] = ..., version: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class GetDarResponse(_message.Message):
    __slots__ = ("payload", "data")
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    payload: bytes
    data: DarDescription
    def __init__(self, payload: _Optional[bytes] = ..., data: _Optional[_Union[DarDescription, _Mapping]] = ...) -> None: ...

class ListDarsRequest(_message.Message):
    __slots__ = ("limit", "filter_name")
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    FILTER_NAME_FIELD_NUMBER: _ClassVar[int]
    limit: int
    filter_name: str
    def __init__(self, limit: _Optional[int] = ..., filter_name: _Optional[str] = ...) -> None: ...

class ListDarsResponse(_message.Message):
    __slots__ = ("dars",)
    DARS_FIELD_NUMBER: _ClassVar[int]
    dars: _containers.RepeatedCompositeFieldContainer[DarDescription]
    def __init__(self, dars: _Optional[_Iterable[_Union[DarDescription, _Mapping]]] = ...) -> None: ...

class GetDarContentsRequest(_message.Message):
    __slots__ = ("main_package_id",)
    MAIN_PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    main_package_id: str
    def __init__(self, main_package_id: _Optional[str] = ...) -> None: ...

class GetDarContentsResponse(_message.Message):
    __slots__ = ("description", "packages")
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    PACKAGES_FIELD_NUMBER: _ClassVar[int]
    description: DarDescription
    packages: _containers.RepeatedCompositeFieldContainer[PackageDescription]
    def __init__(self, description: _Optional[_Union[DarDescription, _Mapping]] = ..., packages: _Optional[_Iterable[_Union[PackageDescription, _Mapping]]] = ...) -> None: ...

class VetDarRequest(_message.Message):
    __slots__ = ("main_package_id", "synchronize", "synchronizer_id")
    MAIN_PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZE_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    main_package_id: str
    synchronize: bool
    synchronizer_id: str
    def __init__(self, main_package_id: _Optional[str] = ..., synchronize: bool = ..., synchronizer_id: _Optional[str] = ...) -> None: ...

class VetDarResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UnvetDarRequest(_message.Message):
    __slots__ = ("main_package_id", "synchronizer_id")
    MAIN_PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    main_package_id: str
    synchronizer_id: str
    def __init__(self, main_package_id: _Optional[str] = ..., synchronizer_id: _Optional[str] = ...) -> None: ...

class UnvetDarResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/participant_status_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/participant/v30/participant_status_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...health.v30 import status_service_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_health_dot_v30_dot_status__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNcom/digitalasset/canton/admin/participant/v30/participant_status_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a=com/digitalasset/canton/admin/health/v30/status_service.proto\"\x1a\n\x18ParticipantStatusRequest\"\x82\x02\n\x15\x43onnectedSynchronizer\x12\x38\n\x18physical_synchronizer_id\x18\x01 \x01(\tR\x16physicalSynchronizerId\x12\x63\n\x06health\x18\x02 \x01(\x0e\x32K.com.digitalasset.canton.admin.participant.v30.ConnectedSynchronizer.HealthR\x06health\"J\n\x06Health\x12\x16\n\x12HEALTH_UNSPECIFIED\x10\x00\x12\x12\n\x0eHEALTH_HEALTHY\x10\x01\x12\x14\n\x10HEALTH_UNHEALTHY\x10\x02\"\xdf\x04\n\x19ParticipantStatusResponse\x12\x82\x01\n\x06status\x18\x01 \x01(\x0b\x32h.com.digitalasset.canton.admin.participant.v30.ParticipantStatusResponse.ParticipantStatusResponseStatusH\x00R\x06status\x12\x63\n\x0fnot_initialized\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.admin.health.v30.NotInitializedH\x00R\x0enotInitialized\x1a\xcf\x02\n\x1fParticipantStatusResponseStatus\x12U\n\rcommon_status\x18\x01 \x01(\x0b\x32\x30.com.digitalasset.canton.admin.health.v30.StatusR\x0c\x63ommonStatus\x12}\n\x17\x63onnected_synchronizers\x18\x02 \x03(\x0b\x32\x44.com.digitalasset.canton.admin.participant.v30.ConnectedSynchronizerR\x16\x63onnectedSynchronizers\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12>\n\x1bsupported_protocol_versions\x18\x04 \x03(\x05R\x19supportedProtocolVersionsB\x06\n\x04kind2\xc3\x01\n\x18ParticipantStatusService\x12\xa6\x01\n\x11ParticipantStatus\x12G.com.digitalasset.canton.admin.participant.v30.ParticipantStatusRequest\x1aH.com.digitalasset.canton.admin.participant.v30.ParticipantStatusResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.participant_status_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_PARTICIPANTSTATUSREQUEST']._serialized_start=192
  _globals['_PARTICIPANTSTATUSREQUEST']._serialized_end=218
  _globals['_CONNECTEDSYNCHRONIZER']._serialized_start=221
  _globals['_CONNECTEDSYNCHRONIZER']._serialized_end=479
  _globals['_CONNECTEDSYNCHRONIZER_HEALTH']._serialized_start=405
  _globals['_CONNECTEDSYNCHRONIZER_HEALTH']._serialized_end=479
  _globals['_PARTICIPANTSTATUSRESPONSE']._serialized_start=482
  _globals['_PARTICIPANTSTATUSRESPONSE']._serialized_end=1089
  _globals['_PARTICIPANTSTATUSRESPONSE_PARTICIPANTSTATUSRESPONSESTATUS']._serialized_start=746
  _globals['_PARTICIPANTSTATUSRESPONSE_PARTICIPANTSTATUSRESPONSESTATUS']._serialized_end=1081
  _globals['_PARTICIPANTSTATUSSERVICE']._serialized_start=1092
  _globals['_PARTICIPANTSTATUSSERVICE']._serialized_end=1287
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .mediator_administration_service_pb2 import MediatorPruning
from .mediator_administration_service_pb2_grpc import MediatorAdministrationServiceStub
from .mediator_initialization_service_pb2 import InitializeMediatorRequest, InitializeMediatorResponse
from .mediator_initialization_service_pb2_grpc import MediatorInitializationServiceStub
from .mediator_inspection_service_pb2 import Quorum, TransactionView, TransactionViews, Verdict, VerdictResult, VerdictsRequest, VerdictsResponse
from .mediator_inspection_service_pb2_grpc import MediatorInspectionServiceStub
from .sequencer_connection_service_pb2 import GetConnectionRequest, GetConnectionResponse, LogoutRequest, LogoutResponse, SetConnectionRequest, SetConnectionResponse
from .sequencer_connection_service_pb2_grpc import SequencerConnectionServiceStub

__all__ = [
    "GetConnectionRequest",
    "GetConnectionResponse",
    "InitializeMediatorRequest",
    "InitializeMediatorResponse",
    "LogoutRequest",
    "LogoutResponse",
    "MediatorAdministrationServiceStub",
    "MediatorInitializationServiceStub",
    "MediatorInspectionServiceStub",
    "MediatorPruning",
    "Quorum",
    "SequencerConnectionServiceStub",
    "SetConnectionRequest",
    "SetConnectionResponse",
    "TransactionView",
    "TransactionViews",
    "Verdict",
    "VerdictResult",
    "VerdictsRequest",
    "VerdictsResponse",
]



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/interactive/interactive_submission_common_data.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/daml/ledger/api/v2/interactive/interactive_submission_common_data.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import value_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKcom/daml/ledger/api/v2/interactive/interactive_submission_common_data.proto\x12\"com.daml.ledger.api.v2.interactive\x1a\"com/daml/ledger/api/v2/value.proto\"\xb8\x01\n\tGlobalKey\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12!\n\x0cpackage_name\x18\x02 \x01(\tR\x0bpackageName\x12/\n\x03key\x18\x03 \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x03key\x12\x12\n\x04hash\x18\x04 \x01(\x0cR\x04hashB\xc7\x01\n\"com.daml.ledger.api.v2.interactiveB)InteractiveSubmissionCommonDataOuterClassZQgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2/interactive\xaa\x02\"Com.Daml.Ledger.Api.V2.Interactiveb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.interactive.interactive_submission_common_data_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.daml.ledger.api.v2.interactiveB)InteractiveSubmissionCommonDataOuterClassZQgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2/interactive\252\002\"Com.Daml.Ledger.Api.V2.Interactive'
  _globals['_GLOBALKEY']._serialized_start=152
  _globals['_GLOBALKEY']._serialized_end=336
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetResourceLimitsRequest(_message.Message):
    __slots__ = ("new_limits",)
    NEW_LIMITS_FIELD_NUMBER: _ClassVar[int]
    new_limits: ResourceLimits
    def __init__(self, new_limits: _Optional[_Union[ResourceLimits, _Mapping]] = ...) -> None: ...

class SetResourceLimitsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetResourceLimitsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetResourceLimitsResponse(_message.Message):
    __slots__ = ("current_limits",)
    CURRENT_LIMITS_FIELD_NUMBER: _ClassVar[int]
    current_limits: ResourceLimits
    def __init__(self, current_limits: _Optional[_Union[ResourceLimits, _Mapping]] = ...) -> None: ...

class ResourceLimits(_message.Message):
    __slots__ = ("max_inflight_validation_requests", "max_submission_rate", "max_submission_burst_factor")
    MAX_INFLIGHT_VALIDATION_REQUESTS_FIELD_NUMBER: _ClassVar[int]
    MAX_SUBMISSION_RATE_FIELD_NUMBER: _ClassVar[int]
    MAX_SUBMISSION_BURST_FACTOR_FIELD_NUMBER: _ClassVar[int]
    max_inflight_validation_requests: int
    max_submission_rate: int
    max_submission_burst_factor: float
    def __init__(self, max_inflight_validation_requests: _Optional[int] = ..., max_submission_rate: _Optional[int] = ..., max_submission_burst_factor: _Optional[float] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from ....topology.admin.v30 import common_pb2 as _common_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FetchTimeRequest(_message.Message):
    __slots__ = ("synchronizer", "freshness_bound")
    SYNCHRONIZER_FIELD_NUMBER: _ClassVar[int]
    FRESHNESS_BOUND_FIELD_NUMBER: _ClassVar[int]
    synchronizer: _common_pb2.Synchronizer
    freshness_bound: _duration_pb2.Duration
    def __init__(self, synchronizer: _Optional[_Union[_common_pb2.Synchronizer, _Mapping]] = ..., freshness_bound: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class FetchTimeResponse(_message.Message):
    __slots__ = ("timestamp",)
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class AwaitTimeRequest(_message.Message):
    __slots__ = ("synchronizer", "timestamp")
    SYNCHRONIZER_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    synchronizer: _common_pb2.Synchronizer
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, synchronizer: _Optional[_Union[_common_pb2.Synchronizer, _Mapping]] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class AwaitTimeResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .party_management_service_pb2 import AddPartyAsyncRequest, AddPartyAsyncResponse, ClearPartyOnboardingFlagRequest, ClearPartyOnboardingFlagResponse, ExportPartyAcsRequest, ExportPartyAcsResponse, GetAddPartyStatusRequest, GetAddPartyStatusResponse, GetHighestOffsetByTimestampRequest, GetHighestOffsetByTimestampResponse, ImportPartyAcsRequest, ImportPartyAcsResponse

__all__ = [
    "PartyManagementServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class PartyManagementServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _PartyManagementServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _PartyManagementServiceAsyncStub: ...  # type: ignore
    def AddPartyAsync(self, __1: AddPartyAsyncRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> AddPartyAsyncResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, AddPartyAsyncResponse]: ...
    def GetAddPartyStatus(self, __1: GetAddPartyStatusRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetAddPartyStatusResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetAddPartyStatusResponse]: ...
    def ExportPartyAcs(self, __1: ExportPartyAcsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[ExportPartyAcsResponse] | _grpc_aio.UnaryStreamCall[_typing.Any, ExportPartyAcsResponse]: ...
    def ImportPartyAcs(self, __1: _typing.Iterable[ImportPartyAcsRequest], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ImportPartyAcsResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ImportPartyAcsResponse]: ...
    def GetHighestOffsetByTimestamp(self, __1: GetHighestOffsetByTimestampRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetHighestOffsetByTimestampResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetHighestOffsetByTimestampResponse]: ...
    def ClearPartyOnboardingFlag(self, __1: ClearPartyOnboardingFlagRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ClearPartyOnboardingFlagResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ClearPartyOnboardingFlagResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _PartyManagementServiceBlockingStub(PartyManagementServiceStub):
    def AddPartyAsync(self, __1: AddPartyAsyncRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> AddPartyAsyncResponse: ...
    def GetAddPartyStatus(self, __1: GetAddPartyStatusRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetAddPartyStatusResponse: ...
    def ExportPartyAcs(self, __1: ExportPartyAcsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[ExportPartyAcsResponse]: ...
    def ImportPartyAcs(self, __1: _typing.Iterable[ImportPartyAcsRequest], timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ImportPartyAcsResponse: ...
    def GetHighestOffsetByTimestamp(self, __1: GetHighestOffsetByTimestampRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetHighestOffsetByTimestampResponse: ...
    def ClearPartyOnboardingFlag(self, __1: ClearPartyOnboardingFlagRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ClearPartyOnboardingFlagResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _PartyManagementServiceAsyncStub(PartyManagementServiceStub):
    def AddPartyAsync(self, __1: AddPartyAsyncRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, AddPartyAsyncResponse]: ...  # type: ignore
    def GetAddPartyStatus(self, __1: GetAddPartyStatusRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetAddPartyStatusResponse]: ...  # type: ignore
    def ExportPartyAcs(self, __1: ExportPartyAcsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, ExportPartyAcsResponse]: ...  # type: ignore
    def ImportPartyAcs(self, __1: _typing.Iterable[ImportPartyAcsRequest], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ImportPartyAcsResponse]: ...  # type: ignore
    def GetHighestOffsetByTimestamp(self, __1: GetHighestOffsetByTimestampRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetHighestOffsetByTimestampResponse]: ...  # type: ignore
    def ClearPartyOnboardingFlag(self, __1: ClearPartyOnboardingFlagRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ClearPartyOnboardingFlagResponse]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....protocol.v30 import traffic_control_parameters_pb2 as _traffic_control_parameters_pb2
from ....topology.admin.v30 import common_pb2 as _common_pb2
from ....v30 import trace_context_pb2 as _trace_context_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SendAsyncRequest(_message.Message):
    __slots__ = ("signed_submission_request",)
    SIGNED_SUBMISSION_REQUEST_FIELD_NUMBER: _ClassVar[int]
    signed_submission_request: bytes
    def __init__(self, signed_submission_request: _Optional[bytes] = ...) -> None: ...

class TrafficControlErrorReason(_message.Message):
    __slots__ = ("error",)
    class Error(_message.Message):
        __slots__ = ("insufficient_traffic", "outdated_traffic_cost")
        INSUFFICIENT_TRAFFIC_FIELD_NUMBER: _ClassVar[int]
        OUTDATED_TRAFFIC_COST_FIELD_NUMBER: _ClassVar[int]
        insufficient_traffic: str
        outdated_traffic_cost: str
        def __init__(self, insufficient_traffic: _Optional[str] = ..., outdated_traffic_cost: _Optional[str] = ...) -> None: ...
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: TrafficControlErrorReason.Error
    def __init__(self, error: _Optional[_Union[TrafficControlErrorReason.Error, _Mapping]] = ...) -> None: ...

class SendAsyncResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SubscriptionRequest(_message.Message):
    __slots__ = ("member", "timestamp")
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    member: str
    timestamp: int
    def __init__(self, member: _Optional[str] = ..., timestamp: _Optional[int] = ...) -> None: ...

class SubscriptionResponse(_message.Message):
    __slots__ = ("signed_sequenced_event", "trace_context")
    SIGNED_SEQUENCED_EVENT_FIELD_NUMBER: _ClassVar[int]
    TRACE_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    signed_sequenced_event: bytes
    trace_context: _trace_context_pb2.TraceContext
    def __init__(self, signed_sequenced_event: _Optional[bytes] = ..., trace_context: _Optional[_Union[_trace_context_pb2.TraceContext, _Mapping]] = ...) -> None: ...

class AcknowledgeRequest(_message.Message):
    __slots__ = ("member", "timestamp")
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    member: str
    timestamp: int
    def __init__(self, member: _Optional[str] = ..., timestamp: _Optional[int] = ...) -> None: ...

class AcknowledgeResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class AcknowledgeSignedRequest(_message.Message):
    __slots__ = ("signed_acknowledge_request",)
    SIGNED_ACKNOWLEDGE_REQUEST_FIELD_NUMBER: _ClassVar[int]
    signed_acknowledge_request: bytes
    def __init__(self, signed_acknowledge_request: _Optional[bytes] = ...) -> None: ...

class AcknowledgeSignedResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DownloadTopologyStateForInitRequest(_message.Message):
    __slots__ = ("member",)
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: str
    def __init__(self, member: _Optional[str] = ...) -> None: ...

class DownloadTopologyStateForInitResponse(_message.Message):
    __slots__ = ("topology_transactions",)
    TOPOLOGY_TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    topology_transactions: _common_pb2.TopologyTransactions
    def __init__(self, topology_transactions: _Optional[_Union[_common_pb2.TopologyTransactions, _Mapping]] = ...) -> None: ...

class DownloadTopologyStateForInitHashRequest(_message.Message):
    __slots__ = ("member",)
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: str
    def __init__(self, member: _Optional[str] = ...) -> None: ...

class DownloadTopologyStateForInitHashResponse(_message.Message):
    __slots__ = ("topology_state_hash",)
    TOPOLOGY_STATE_HASH_FIELD_NUMBER: _ClassVar[int]
    topology_state_hash: bytes
    def __init__(self, topology_state_hash: _Optional[bytes] = ...) -> None: ...

class GetTrafficStateForMemberRequest(_message.Message):
    __slots__ = ("member", "timestamp")
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    member: str
    timestamp: int
    def __init__(self, member: _Optional[str] = ..., timestamp: _Optional[int] = ...) -> None: ...

class GetTrafficStateForMemberResponse(_message.Message):
    __slots__ = ("traffic_state",)
    TRAFFIC_STATE_FIELD_NUMBER: _ClassVar[int]
    traffic_state: _traffic_control_parameters_pb2.TrafficState
    def __init__(self, traffic_state: _Optional[_Union[_traffic_control_parameters_pb2.TrafficState, _Mapping]] = ...) -> None: ...

class GetTimeRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetTimeResponse(_message.Message):
    __slots__ = ("sequencing_timestamp",)
    SEQUENCING_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    sequencing_timestamp: int
    def __init__(self, sequencing_timestamp: _Optional[int] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.map_string import MapString


T = TypeVar("T", bound="ObjectMeta")


@_attrs_define
class ObjectMeta:
    """Represents metadata corresponding to a participant resource (e.g. a participant user or participant local
    information about a party).

    Based on ``ObjectMeta`` meta used in Kubernetes API.
    See https://github.com/kubernetes/apimachinery/blob/master/pkg/apis/meta/v1/generated.proto#L640

        Attributes:
            resource_version (str): An opaque, non-empty value, populated by a participant server which represents the
                internal version of the resource
                this ``ObjectMeta`` message is attached to. The participant server will change it to a unique value each time
                the corresponding resource is updated.
                You must not rely on the format of resource version. The participant server might change it without notice.
                You can obtain the newest resource version value by issuing a read request.
                You may use it for concurrent change detection by passing it back unmodified in an update request.
                The participant server will then compare the passed value with the value maintained by the system to determine
                if any other updates took place since you had read the resource version.
                Upon a successful update you are guaranteed that no other update took place during your read-modify-write
                sequence.
                However, if another update took place during your read-modify-write sequence then your update will fail with an
                appropriate error.
                Concurrent change control is optional. It will be applied only if you include a resource version in an update
                request.
                When creating a new instance of a resource you must leave the resource version empty.
                Its value will be populated by the participant server upon successful resource creation.
                Optional
            annotations (MapString):
    """

    resource_version: str
    annotations: MapString
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        resource_version = self.resource_version

        annotations = self.annotations.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "resourceVersion": resource_version,
                "annotations": annotations,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.map_string import MapString

        d = dict(src_dict)
        resource_version = d.pop("resourceVersion")

        annotations = MapString.from_dict(d.pop("annotations"))

        object_meta = cls(
            resource_version=resource_version,
            annotations=annotations,
        )

        object_meta.additional_properties = d
        return object_meta

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
